===============================
:code:`Trakt['users/settings']`
===============================

.. automodule:: trakt.interfaces.users.settings

  .. autoclass:: UsersSettingsInterface
    :members: get
    :undoc-members:
